Prevent Breast Cancer - California Protons
Description: Understanding the underlying causes and risk factors of breast cancer is imperative for prevention. Learn whether you are at risk and what steps you can take to prevent breast cancer.

Prevent Breast
Cancer

Overview

Diagnosis

Treatments

Causes & Risks

Stages & Grades

# Know the Causes.
Understand Your Risks.

Once in your 20s, it’s important to stay on top of your health and perform regular breast exams. Breast cancer is the most common female cancer worldwide and about 1 in 8 women in the United States will be diagnosed with it sometime in their lifetimes. This percentage increases to 72% for those who have a BRCA1 mutation or BRCA2 mutation. However, breast cancer can be highly curable, especially when caught early.

## Main Causes of Breast Cancer

Cancer is largely caused by mutations or changes to the genetic material found in your cells. Some mutations you’re born with, while others are acquired later in life due to errors in the gene replication process. In most cases, cancer develops when cells cease their normal functions and start to allow rapid growth, fail to stop uncontrolled cell growth or make mistakes when repairing DNA errors. Keep in mind, not all acquired or inherited genetic mutations become cancer.

## Common Breast Cancer Risk Factors

While doctors have found some correlations between certain health conditions and cases diagnosed, the majority of cancers occur in people without any known risk factors. Your best approach is to manage what you can control, change what you can and stay aware of changes in your health that could be a cause of breast cancer.

- Age: Cancer can develop at any age, but 2 out of 3 invasive breast cancers are found in women 55 or older.
- Race/ethnicity: Ashkenazi Jewish (Eastern European) heritage can put you at greater risk. Caucasian women are slightly more likely to develop breast cancer than those of African American, Hispanic and Asian descent. However, African American women are more likely to develop more aggressive breast cancer at a younger age.
- Inherited genetic mutations: BRCA1, BRCA2 and CHEC2 abnormalities can be traced to 5-10% of all cases.
- Family history: Your genetic risk of breast cancer doubles if you’ve had one first-degree relative—sister, mother or daughter—diagnosed with breast cancer. If you’ve had two first-degree relatives diagnosed, your risk is 5 times higher than average. Blood relatives diagnosed before the age of 50 or with triple-native breast cancer can also increase your risk.
- Childbirth and menstruation cycles: If you haven’t had a full-term pregnancy or your first child before the age of 30, you might have a higher risk of getting breast cancer. Starting your period before the age of 12 and going through menopause after the age of 55 may also increase your risk.
- Lifestyle and environmental causes: Smoking, drinking, lack of exercise, a BMI over 25, chronic inflammation, low levels of vitamin D, excessive exposure to the sun or cancer-causing chemicals and having unsafe sex can contribute to the development of cancerous cells.

## Breast Cancer Prevention Tips

There is no proven strategy for prevention but forming a healthy lifestyle and taking the proper health measures may help reduce your risk and improve your immunity. Recent studies suggest that diet is at least partly responsible for 30 to 40% of all cancers.

### 1. Avoid smoking

Smoke contains carcinogenic compounds that can cause cancer. It also makes you more prone to treatment-related side effects. If radiation is required, you may face a greater risk of developing lung cancer and/or pneumonitis.

### 2. Exercise regularly

Exercise helps you control blood sugar and limits insulin levels of a hormone that can affect how breast cells grow and develop cancer-causing genetic mutations. Aim for at least 150 minutes a week of moderate aerobic activity or 75 minutes of vigorous aerobic activity.

### 3. Maintain a healthy weight (under 25 BMI)

Fat cells make estrogen, which can stimulate the development and growth of certain types of breast cancer. Extra fat cells can also trigger inflammation in the body, which has been linked to a higher chance of recurrence.

### 4. Follow a breast cancer prevention diet, by choosing to:

- Maintain a diet rich in fruit and vegetables
- Pick whole grains, lean proteins and non-fat milk and dairy products
- Remove the skin and fat from meat, poultry and fish
- Limit sugar, refined carbohydrates and alcohol
- Eat smaller sized portions

### 5. Avoid harmful exposure to chemicals, toxins, the sun and other radiation

More studies are starting to research the environmental causes of breast cancer and impact of certain chemicals found in plastic, cosmetics, food, water and other consumer products. The use of pesticides, antibiotics, and hormones in food production may also play roles.

### 6. Schedule annual breast exams

Early detection is still the best way to prevent cancer from growing or spreading. With 5-year survival rates around 100% for Stage 0 and Stage 1 breast cancer, catching it early is key.

### 7. See a doctor if you start experiencing symptoms of breast cancer such as:

- Fatigue
- Lump or thickening area felt under the skin
- Unintended weight loss or gain
- Skin changes, such as yellowing, darkening or redness of the skin
- Unexplained bleeding, bruising or sores that won’t heal
- Changes in bowel or bladder habits
- Persistent cough, trouble breathing, indigestion or discomfort after eating
- Hoarseness or difficulty swallowing
- Persistent, unexplained fevers, night sweats or muscle and/or joint pain

## Preventative Breast Cancer Treatment Options

A family history of breast cancer and/or a known genetic mutation can cause stress and anxiety for many women. Rather than wait and see, some women choose to take a more proactive and aggressive approach to reduce their chances. The most common being the removal of their breast(s) and/or ovaries and suppression of the estrogen hormone linked to cancer cell growth. While there is no guarantee, it’s good to familiarize yourself with the types of preventive treatments available to you.

### Prophylactic mastectomy

According to the National Cancer Institute, women who carry a BRCA1 or BRCA2 gene mutation and opt for a preventive mastectomy may be able to reduce their risk of cancer developing by 95%. This percentage drops slightly to 90% for women with a strong family history of breast cancer. During this surgical operation, one or both breasts will be removed to reduce the risk cancer forming in your breast. The amount of tissue removed depends on the type of mastectomy (e.g., total, skin-sparing and nipple-saving) performed. Breast reconstruction may also be an option during or after surgery.

Learn More

### Prophylactic ovary removal

This type of surgery gives women an option who want to lower their risk without causing major visible changes to their body. The removal of your ovaries lowers the amount of estrogen in the body, which helps prevent breast cancers that require estrogen to grow. The National Cancer Institute has found this surgery reduces the number of new cases among high-risk women by around 50%. It’s important to note this type of surgery only benefits pre-menopausal women and eliminates the ability to have children.

Learn More

### Preventive hormone therapy

This type of treatment is often recommended for those who haven’t been diagnosed but are thought to be at risk for ER- and PR-positive breast cancers. Certain hormones in the blood can cause these cancers to form in the breast tissue. By taking these hormone-blocking drugs, you can lower the production of estrogen in the blood and stop the stimulation of breast cells. Hormone therapy doesn’t affect tumors that are ER- and PR-negative because they’re not influenced by hormones.

Learn More

## Learn more about breast cancer

Exams & Diagnosis for Breast Cancer

Stages & Grades of Breast Cancer

Treatment Options for Breast Cancer

English
Afrikaans Albanian Amharic Arabic Armenian Azerbaijani Basque Belarusian Bengali Bosnian Bulgarian Catalan Cebuano Chichewa Chinese (Simplified) Chinese (Traditional) Corsican Croatian Czech Danish Dutch English Esperanto Estonian Filipino Finnish French Frisian Galician Georgian German Greek Gujarati Haitian Creole Hausa Hawaiian Hebrew Hindi Hmong Hungarian Icelandic Igbo Indonesian Irish Italian Japanese Javanese Kannada Kazakh Khmer Korean Kurdish (Kurmanji) Kyrgyz Lao Latin Latvian Lithuanian Luxembourgish Macedonian Malagasy Malay Malayalam Maltese Maori Marathi Mongolian Myanmar (Burmese) Nepali Norwegian Pashto Persian Polish Portuguese Punjabi Romanian Russian Samoan Scottish Gaelic Serbian Sesotho Shona Sindhi Sinhala Slovak Slovenian Somali Spanish Sudanese Swahili Swedish Tajik Tamil Telugu Thai Turkish Ukrainian Urdu Uzbek Vietnamese Welsh Xhosa Yiddish Yoruba Zulu

## Contact Us

First Name*
Last Name*
Email Address*
Phone Number*
How did you hear about us?*
Message

## Register

- First Name*
- Last Name*
- Title*
- If other, please specify
- Affiliation*
- Street Address Address Line 2 City State
  ZIP Code
- Email*
- Specialty
- If other, please specify
- How did you hear about this activity?
  - Brochure / Postcard in the Mail
  - Email Announcement
  - Personal Letter / Invitation
  - Director / Supervisor
  - Other
- If other, please specify
- Comments
  This field is for validation purposes and should be left unchanged.